<?php

namespace App\Http\Controllers\admin;
use DB;
use Storage;
use App\Classes\table;
use App\Classes\permission;
use App\Http\Requests;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Crypt;
use App\Http\Controllers\Controller;

class ReasonsController extends Controller
{
    public function index() 
    {
		if (permission::permitted('reason-for-visits')=='fail'){ return redirect()->route('denied'); }

        $reasons = table::reasons()->get();

        return view('admin.fields.reason-for-visits', compact('reasons'));
    }

    public function addReason(Request $request)
    {
		if (permission::permitted('reason-for-visits-add')=='fail'){ return redirect()->route('denied'); }

		$v = $request->validate([
		'reason' => 'required|alpha_dash_space|max:200',
		]);

		$reason = mb_strtoupper($request->reason);

		table::reasons()->insert([
		['reason' => $reason],
		]);

		return redirect('reason-for-visits')->with('success', trans("New reason for visits is added!"));
    }

    public function deleteReason($id, Request $request)
    {
		if (permission::permitted('reason-for-visits-delete')=='fail'){ return redirect()->route('denied'); }

		table::reasons()->where('id', $id)->delete();

		return redirect('reason-for-visits')->with('success', trans("Deleted!"));
    }

    function csvToArray($filename) 
    {
    	if( !file_exists($filename) || !is_readable($filename) ) 
    	{
    		return false;
    	}

    	$header = null;
    	if (($handle = fopen($filename, 'r')) !== false) 
    	{
    		while(($row = fgetcsv($handle, 1000, ',')) !== false) 
    		{
				if (!$header) 
				{
    				$header = $row;
    			} else {
    				$data[] = $row;
    			}
    		}
    		fclose($handle);
    	} 
    	return $data;
    }

    function importReasons(Request $request) 
	{
		if (permission::permitted('reason-for-visits-import')=='fail'){ return redirect()->route('denied'); }

		$uploadedfile = $request->file('csv');
		if ($uploadedfile != null) 
		{
			$name = $request->file('csv')->getClientOriginalName();
			$destinationPath = storage_path() . '/app/';
			$uploadedfile->move($destinationPath, $name);
	
			$file = storage_path('app/' . $name);
			$array = $this->csvToArray($file);
			
			foreach ($array as $value) 
			{
				table::reasons()->insert([
					[ 'id' => $value[0], 'reason' => $value[1] ],
				]);
			}

			return redirect('reason-for-visits');
		} else {
			return redirect('reason-for-visits')->with('error', trans("Whoops!, Please upload a csv file."));
		}
	}

    function exportReasons(Request $request) 
	{
		if (permission::permitted('reason-for-visits-export')=='fail'){ return redirect()->route('denied'); }
		
		$date = date('Y-m-d');
        $time = date('h-i-sa');
		$file = 'reson-for-visits-'.$date.'T'.$time.'.csv';

		$c = table::reasons()->get();

		Storage::put($file, '', 'private');

		foreach ($c as $d) 
		{
		    Storage::prepend($file, $d->id .','. $d->reason);
		}

		Storage::prepend($file, '"ID"' .','. 'REASON');

		return Storage::download($file);
    }

}
