<?php

namespace App\Http\Controllers\admin;
use DB;
use App\Classes\table;
use App\Classes\permission;
use App\Http\Requests;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Crypt;
use App\Http\Controllers\Controller;

class VisitorLogController extends Controller
{

    public function index(Request $request) 
    {
        if (permission::permitted('visitor-log')=='fail'){ return redirect()->route('denied'); }

        $visitors = table::visitorlog()->get();
        $reasons = table::reasons()->get();
        
        return view("admin.visitor-log", compact("visitors", "reasons"));
    }

    public function add(Request $request)
    {
        if (permission::permitted('visitor-log-add')=='fail'){ return redirect()->route('denied'); }

        $v = $request->validate([
            'date' => 'required|max:20',
            'firstname' => 'required|max:100',
            'lastname' => 'required|max:100',
            'reasonforvisit' => 'required|max:200',
            'visitorfrom' => 'required|max:100',
            'timein' => 'max:15',
            'timeout' => 'max:15',
        ]);

        $firstname = mb_strtoupper($request->firstname);
        $lastname = mb_strtoupper($request->lastname);
        $reasonforvisit = mb_strtoupper($request->reasonforvisit);
        $visitorfrom = mb_strtoupper($request->visitorfrom);

    	table::visitorlog()->insert([
    		[
                'date' => $request->date,
                'firstname' => $firstname,
				'lastname' => $lastname,
				'reasonforvisit' => $reasonforvisit,
				'visitorfrom' => $visitorfrom,
				'timein' => $request->timein,
				'timeout' => $request->timeout,
            ],
    	]);

    	return redirect("/visitor-log")->with("success", trans("New visitor added successfully."));
    }

    public function get(Request $request) 
    {
        if (permission::permitted('visitor-log-view')=='fail'){ return redirect()->route('denied'); }

        $id = $request->id;
        $data = table::visitorlog()->where('id', $id)->first();

        return response()->json([
            "id" => Crypt::encryptString($id),
            "date" => $data->date,
            "firstname" => $data->firstname,
            "lastname" => $data->lastname,
            "reasonforvisit" => $data->reasonforvisit,
            "visitorfrom" => $data->visitorfrom,
            "timein" => $data->timein,
            "timeout" => $data->timeout,
        ]);
    }

    public function update(Request $request) 
    {
        if (permission::permitted('visitor-log-edit')=='fail'){ return redirect()->route('denied'); }

        $v = $request->validate([
            'date' => 'required|max:20',
            'firstname' => 'required|max:100',
            'lastname' => 'required|max:100',
            'reasonforvisit' => 'required|max:200',
            'visitorfrom' => 'required|max:100',
            'timein' => 'max:15',
            'timeout' => 'max:15',
        ]);

        $id = Crypt::decryptString($request->id);

        table::visitorlog()->where('id', $id)->update([
            'date' => $request->date,
            'firstname' => $request->firstname,
            'lastname' => $request->lastname,
            'reasonforvisit' => $request->reasonforvisit,
            'visitorfrom' => $request->visitorfrom,
            'timein' => $request->timein,
            'timeout' => $request->timeout,
        ]);

        return redirect("/visitor-log")->with("success", trans("Visitor information is up to date!"));
    }

    public function delete($id, Request $request) 
    {
        if (permission::permitted('visitor-log-delete')=='fail'){ return redirect()->route('denied'); }

        table::visitorlog()->where('id', $id)->delete();

        return redirect("/visitor-log")->with("success", trans("Visitor information is deleted!"));
    }

    public function timeline(Request $request) 
    {   
        if (permission::permitted('timeline')=='fail'){ return redirect()->route('denied'); }
        
        $currentdate =  date("Y-m-d");

        $data = table::visitorlog()->where("date", $currentdate)->get(); 

        return  view("admin.visitor-timeline", compact("data"));
    }

    public function kiosk(Request $request)
    {
        if (permission::permitted('visitor-kiosk')=='fail'){ return redirect()->route('denied'); }

        $reasons = table::reasons()->get();
        $visitor_checkout = table::visitorlog()->where("timeout", NULL)->get();
        $data = table::settings()->where('id', 1)->first();
        $tz = $data->timezone;
        $tf = $data->time_format;

        return view("admin.visitor-kiosk", compact("reasons", "visitor_checkout", "tz", "tf"));
    }

    public function getVisitor(Request $request) 
    {
        if (permission::permitted('visitor-kiosk')=='fail'){ return redirect()->route('denied'); }
        
        if($request->id == null) {
            return response()->json([
                "error" => "Invalid request!"
            ]);
        }

        $id = $request->id;
        $data = table::visitorlog()->where('id', $id)->get();

        foreach ($data as $d) 
        {
            $id = $d->id;
            $date = $d->date;
            $firstname = $d->firstname;
            $lastname = $d->lastname;
            $reasonforvisit = $d->reasonforvisit;
            $visitorfrom = $d->visitorfrom;
            $timein = $d->timein;
        }

        return response()->json([
            "id" => Crypt::encryptString($id),
            "date" => $date,
            "firstname" => $firstname,
            "lastname" => $lastname,
            "reasonforvisit" => $reasonforvisit,
            "visitorfrom" => $visitorfrom,
            "timein" => $timein,
        ]);
    }

    public function visitorCheckin(Request $request) 
    {
        if (permission::permitted('visitor-kiosk')=='fail'){ return redirect()->route('denied'); }

        $firstname = $request->firstname;
        $lastname = $request->lastname;
        $reasonforvisit = $request->reasonforvisit;
        $visitorfrom = $request->visitorfrom;
        $date = date("Y-m-d", strtotime($request->date));
        $time = date("h:i A", strtotime($request->time));

        // validation
        if($firstname == null || $lastname == null || $reasonforvisit == null || $visitorfrom == null || $date == null || $time == null) {
            return response()->json([
                "error" => "Please fill the form completely!"
            ]);
        }

        // save check in info to database
        table::visitorlog()->insert([
            'date' => $date,
            'firstname' => mb_strtoupper($firstname),
            'lastname' => mb_strtoupper($lastname),
            'reasonforvisit' => mb_strtoupper($reasonforvisit),
            'visitorfrom' => mb_strtoupper($visitorfrom),
            'timein' => $time,
        ]);

        return response()->json([
            "success" => "You are now signed in!",
            "name" => "$firstname $lastname",
            "date" => $date,
            "time" => $time,
        ]);
    }

    public function visitorCheckout(Request $request)
    {
        if (permission::permitted('visitor-kiosk')=='fail'){ return redirect()->route('denied'); }
        
        // validation
        if($request->time == null || $request->id == null) {
            return response()->json([
                "error" => "Invalid request!"
            ]);
        }

        $id = Crypt::decryptString($request->id);
        $timeout = date("h:i A", strtotime($request->time));

        $data = table::visitorlog()->where("id", $id)->first();
        $name = "$data->firstname $data->lastname";

        // save checkout info to database
        table::visitorlog()->where("id", $id)->update([
            'timeout' => $timeout
        ]);

        return response()->json([
            "success" => "Your are now signed out!",
            "name" => $name,
            "time" => $timeout,
        ]);
    }

}
