<?php

use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

/*
|--------------------------------------------------------------------------
| Welcome Login Page
|--------------------------------------------------------------------------
*/
Route::get('/', 'Auth\LoginController@welcome_login');

/*
|--------------------------------------------------------------------------
| Visitor Kiosk
|--------------------------------------------------------------------------
*/
Route::get('visitor-kiosk', 'Admin\VisitorLogController@kiosk')->name('visitorkiosk');
Route::get('visitor-kiosk/get', 'Admin\VisitorLogController@getVisitor');
Route::get('visitor-kiosk/checkin', 'Admin\VisitorLogController@visitorCheckin');
Route::get('visitor-kiosk/checkout', 'Admin\VisitorLogController@visitorCheckout');

Route::group(['middleware' => 'auth'], function () {

	Route::group(['middleware' => 'checkstatus'], function () {
			/*
			|--------------------------------------------------------------------------
			| Dashboard 
			|--------------------------------------------------------------------------
			*/
			Route::get('dashboard', 'Admin\DashboardController@index')->name('dashboard');	

			/*
			|--------------------------------------------------------------------------
			| Visitor Log 
			|--------------------------------------------------------------------------
			*/
			Route::get('visitor-log', 'Admin\VisitorLogController@index')->name('visitorlog');
			Route::post('visitor-log/add',  'Admin\VisitorLogController@add');
			Route::get('visitor-log/get',  'Admin\VisitorLogController@get');
			Route::post('visitor-log/update',  'Admin\VisitorLogController@update');
			Route::get('visitor-log/delete/{id}', 'Admin\VisitorLogController@delete');

			/*
			|--------------------------------------------------------------------------
			| Visitor Timeline 
			|--------------------------------------------------------------------------
			*/
			Route::get('visitor-timeline', 'Admin\VisitorLogController@timeline')->name('visitortimeline');

			/*
			|--------------------------------------------------------------------------
			| Reason for Visits 
			|--------------------------------------------------------------------------
			*/
			Route::get('reason-for-visits', 'Admin\ReasonsController@index')->name('reasons');
			Route::post('reason-for-visits/add',  'Admin\ReasonsController@addReason');
			Route::get('reason-for-visits/delete/{id}',  'Admin\ReasonsController@deleteReason');
			Route::get('reason-for-visits/export', 'Admin\ReasonsController@exportReasons');
			Route::post('reason-for-visits/import', 'Admin\ReasonsController@importReasons');

			/*
			|--------------------------------------------------------------------------
			| Users 
			|--------------------------------------------------------------------------
			*/
			Route::get('users', 'Admin\UsersController@index')->name('users');
			Route::get('users/enable/{id}', 'Admin\UsersController@enable');
			Route::get('users/disable/{id}', 'Admin\UsersController@disable');
			Route::get('users/edit/{id}', 'Admin\UsersController@edit');
			Route::get('users/delete/{id}', 'Admin\UsersController@delete');
			Route::post('users/register', 'Admin\UsersController@register');
			Route::post('users/update/user', 'Admin\UsersController@update');

			/*
			|--------------------------------------------------------------------------
			| Users Roles & Permission
			|--------------------------------------------------------------------------
			*/
			Route::get('users/roles', 'Admin\RolesController@index')->name('roles');
			Route::post('users/roles/add', 'Admin\RolesController@add');
			Route::get('user/roles/get', 'Admin\RolesController@get');
			Route::post('users/roles/update', 'Admin\RolesController@update');
			Route::get('users/roles/delete/{id}', 'Admin\RolesController@delete');
			Route::get('users/roles/permissions/edit/{id}', 'Admin\RolesController@editperm');
			Route::post('users/roles/permissions/update', 'Admin\RolesController@updateperm');

			/*
			|--------------------------------------------------------------------------
			| Update User 
			|--------------------------------------------------------------------------
			*/
			Route::get('update-profile', 'Admin\ProfileController@viewProfile')->name('updateProfile');
			Route::get('update-password', 'Admin\ProfileController@viewPassword')->name('updatePassword');
			Route::post('user/update-profile', 'Admin\ProfileController@updateUser');
			Route::post('user/update-password', 'Admin\ProfileController@updatePassword');

			/*
			|--------------------------------------------------------------------------
			| Settings 
			|--------------------------------------------------------------------------
			*/
			Route::get('settings', 'Admin\SettingsController@index')->name('settings');
			Route::post('settings/update', 'Admin\SettingsController@update');

	});

});

Auth::routes();
Route::get('lang/{locale}', 'LanguageController@lang');
Route::get('logout', 'Auth\LoginController@logout')->name('logout');
Route::view('permission-denied', 'errors.permission-denied')->name('denied');
Route::view('account-disabled', 'errors.account-disabled')->name('disabled');
Route::view('account-not-found', 'errors.account-not-found')->name('notfound');
