(function() {
    "use strict";

    var timezone = document.getElementById('timezone').value;
    var timeformat = document.getElementById('timeformat').value;

    // elements day, time, date
    var elTime = document.getElementById('show_time');
    var elOutTime = document.getElementById('show_outtime');
    var elDate = document.getElementById('show_date');

    // time function to prevent the 1s delay
    var setTime = function() {
        // initialize clock with timezone
        var time = moment().tz(timezone);

        // set time in html
        if (timeformat == 1) {
            elTime.value = time.format("hh:mm:ss A");
            elOutTime.value = time.format("hh:mm:ss A");
        } else {
            elTime.value = time.format("kk:mm:ss");
            elOutTime.value = time.format("kk:mm:ss");
        }

        // set date in html
        elDate.value = time.format('YYYY-MM-DD');

        // set day in html
        // elDay.innerHTML = time.format('dddd');
    }

    setTime();
    setInterval(setTime, 1000);

    function clearNotempty() {
        $('input, textarea').each(function(index, el) {
            var input = $(this).val();
            if (input !== '') {
                $(this).addClass('notempty');
            } else {
                $(this).removeClass('notempty');
            };
        });

        $('.ui.dropdown.selection, .ui.search.dropdown').each(function(index, el) {
            var dropdown = $(this).find('select').val();
            var selected = $(this).find('.menu .item.active.selected').attr('data-value');
            if (dropdown !== '' && selected !== undefined || selected !== '' && selected !== undefined) {
                $(this).addClass('notempty');
            } else {
                $(this).removeClass('notempty');
            };
        });

        $('.ui.dropdown.selection, .ui.search.dropdown').focusout(function(event) {
            var dd = $(this).find('select').val();
            var selected = $(this).find('.menu .item.active.selected').attr('data-value');
            if (dd !== '' && selected !== undefined || selected !== '' && selected !== undefined) {
                $(this).addClass('notempty');
            } else {
                $(this).removeClass('notempty');
            };
        });
    }

    $('.kiosk').on("click", function() {
        var data = $(this).data("type");
        if (data == "checkin") {
            $('#show-check-in-form').slideDown('200');
            $('#show-check-out-form').hide();
        } else {
            $('#show-check-out-form').slideDown('200');
            $('#show-check-in-form').hide();
        }
        $('.kiosk').removeClass('active animated fadeIn');
        $(this).toggleClass('active animated fadeIn');
    });

    $('#show-check-out-form .ui.search.dropdown').on("change", function(e) {
        e.preventDefault();
        var data = $(this).find('select').val();
        var url = $("#url").val();

        $.ajax({
            url: url + '/visitor-kiosk/get',
            type: 'get',
            dataType: 'json',
            data: { id: data },
            headers: { 'X-CSRF-Token': $('meta[name="csrf-token"]').attr('content') },

            success: function(response) {
                $('#show-check-out-form input[name="id"]').val(response['id']);
                $('#show-check-out-form input[name="name"]').val(response['firstname'] + " " + response['lastname']);
                $('#show-check-out-form input[name="reasonforvisit"]').val(response['reasonforvisit']);
                $('#show-check-out-form input[name="visitorfrom"]').val(response['visitorfrom']);
                $('#show-check-out-form input[name="date"]').val(response['date']);
                $('#show-check-out-form input[name="checkin"]').val(response['timein']);
                $('.check-out-message').toggleClass('hidden').slideDown("200");
            }
        })
    });

    $("#checkin").on("click", function(e) {
        e.preventDefault();
        var firstname, lastname, reasonforvisit, visitorfrom, date, time;
        var url = $("#url").val();

        firstname = $('#show-check-in-form input[name="firstname"]').val();
        lastname = $('#show-check-in-form input[name="lastname"]').val();
        reasonforvisit = $('#show-check-in-form select[name="reasonforvisit"]').val();
        visitorfrom = $('#show-check-in-form input[name="visitorfrom"]').val();
        date = $('#show-check-in-form input[name="date"]').val();
        time = $('#show-check-in-form input[name="time"]').val();

        $("#show-check-in-form").form('clear');
        clearNotempty();

        $.ajax({
            type: "get",
            url: url + '/visitor-kiosk/checkin/',
            dataType: 'json',
            data: { firstname: firstname, lastname: lastname, reasonforvisit: reasonforvisit, visitorfrom: visitorfrom, date: date, time: time },
            headers: { 'X-CSRF-Token': $('meta[name="csrf-token"]').attr('content') },

            success: function(response) {
                if (response['error'] == undefined) {
                    // check in success
                    $('.ui.checkin.modal').modal('show');
                    $('.ui.checkin.modal .header.title').text(response['success']);
                    $('.ui.checkin.modal .content .name').text(response['name']);
                    $('.ui.checkin.modal .content .time').text(response['time']);

                    // auto-hide modal
                    setTimeout(() => {
                        $('.ui.checkin.modal').modal('hide');
                    }, 5000);
                } else {
                    // error content
                    $('.ui.checkinerror.modal').modal('show');

                    // auto-hide modal
                    setTimeout(() => {
                        $('.ui.checkinerror.modal').modal('hide');
                    }, 5000);
                }
            }
        })
    });

    $("#checkout").on("click", function(e) {
        e.preventDefault();
        var timeout, id, url;
        url = $("#url").val();
        timeout = $('#show-check-out-form input[name="checkout"]').val();
        id = $('#show-check-out-form input[name="id"]').val();

        $('.check-out-message').toggleClass('hidden');

        $.ajax({
            type: "get",
            url: url + '/visitor-kiosk/checkout/',
            dataType: 'json',
            data: { time: timeout, id: id },
            headers: { 'X-CSRF-Token': $('meta[name="csrf-token"]').attr('content') },

            success: function(response) {
                if (response['error'] == undefined) {
                    // check in success
                    $('.ui.checkout.modal').modal('show');
                    $('.ui.checkout.modal .header.title').text(response['success']);
                    $('.ui.checkout.modal .content .name').text(response['name']);
                    $('.ui.checkout.modal .content .time').text(response['time']);

                    // auto-hide modal
                    setTimeout(() => {
                        $('.ui.checkout.modal').modal('hide');
                    }, 5000);
                } else {
                    // error content
                    $('.ui.checkinerror.modal').modal('show');

                    // auto-hide modal
                    setTimeout(() => {
                        $('.ui.checkinerror.modal').modal('hide');
                    }, 5000);
                }
            }
        })
    });

})();

