/*
 * Frontdesk - Visitor Management System
 * Email: official.codefactor@gmail.com
 * Version: 2
 * Author: Brian Luna
 * Copyright 2020 Codefactor
 */

/*
 * Semantic UI extension detect if form inputs are not empty and not empty class
 */
(function() {
    "use strict";

    $(document).ready(function() {
        $('input, textarea').each(function(index, el) {
            var input = $(this).val();
            if (input !== '') {
                $(this).addClass('notempty');
            };
        });

        $('input, textarea').focusout(function(event) {
            var notempty = $(this).val();
            if (notempty !== '') {
                $(this).addClass('notempty');
            }
        });

        $('.ui.dropdown.selection, .ui.search.dropdown').each(function(index, el) {
            var dropdown = $(this).find('select').val();
            var selected = $(this).find('.menu .item.active.selected').attr('data-value');
            if (dropdown !== '' && selected !== undefined || selected !== '' && selected !== undefined) {
                $(this).addClass('notempty');
            }
        });

        $('.ui.dropdown.selection, .ui.search.dropdown').focusout(function(event) {
            var dd = $(this).find('select').val();
            var selected = $(this).find('.menu .item.active.selected').attr('data-value');
            if (dd !== '' && selected !== undefined || selected !== '' && selected !== undefined) {
                $(this).addClass('notempty');
            }
        });
    });

    /*
     * Auto-hide sidebar on window resize if window size is small
     */
    $(window).resize(function() {
        if ($(window).width() <= 768) {
            $('#sidebar, #body').addClass('active');
        }
    });

    /*
     * Semantic UI components initialization
     */
    $('.dropdown').dropdown();
    $('.ui.dropdown').dropdown();
    $('.ui.checkbox').checkbox();
    $('.ui.radio.checkbox').checkbox();
    $('.ui.modal').modal();
    $('.ui.basic.modal').modal();
    $('.ui.add.modal').modal('attach events', '.btn-add', 'toggle');
    $('.ui.edit.modal').modal('attach events', '.btn-edit', 'toggle');
    $('.ui.modal.import').modal('attach events', '.btn-import', 'toggle');

    /*
     * Toggle sidebar on Menu button click
     */
    $('#slidesidebar').on('click', function() {
        $('#sidebar').toggleClass('active');
        $('#body').toggleClass('active');
    });

    /*
     * Hide form message
     */
    $('.message .close').on('click', function() {
        $(this).closest('.message').transition('fade');
    });

    /*
     * Prevent Semantic UI modal exit on submit button 
     */
    $('.ui.modal.add,.ui.modal.edit').modal({
        onDeny: function() {
            return true;
        },
        onApprove: function() {
            return false;
        }
    });

    /*
     * Client-side form validations
     */
    $('#add_reasons_form').form({
        fields: {
            reason: {
                identifier: 'reason',
                rules: [{
                    type: 'empty',
                    prompt: 'Please enter a reason name'
                }]
            },
        }
    });

    $('#add_visitor_form, #edit_visitor_form').form({
        fields: {
            firstname: {
                identifier: 'firstname',
                rules: [{
                    type: 'empty',
                    prompt: 'Please enter First name'
                }]
            },
            lastname: {
                identifier: 'lastname',
                rules: [{
                    type: 'empty',
                    prompt: 'Please enter Last name'
                }]
            },
            reasonforvisit: {
                identifier: 'reasonforvisit',
                rules: [{
                    type: 'empty',
                    prompt: 'Please select a Reason for visit'
                }]
            },
            visitorfrom: {
                identifier: 'visitorfrom',
                rules: [{
                    type: 'empty',
                    prompt: 'Please enter Visitor from'
                }]
            },
            date: {
                identifier: 'date',
                rules: [{
                    type: 'empty',
                    prompt: 'Please enter the Date'
                }]
            },
            timein: {
                identifier: 'timein',
                rules: [{
                    type: 'empty',
                    prompt: 'Please enter Time in'
                }]
            },
            timeout: {
                identifier: 'timeout',
                rules: [{
                    type: 'empty',
                    prompt: 'Please enter Time out'
                }]
            },
        }
    });

    $('#add_user_form').form({
        fields: {
            name: {
                identifier: 'name',
                rules: [{
                    type: 'empty',
                    prompt: 'Please enter a Name'
                }]
            },
            email: {
                identifier: 'email',
                rules: [{
                    type: 'email',
                    prompt: 'Please enter an Email address'
                }]
            },
            role_id: {
                identifier: 'role_id',
                rules: [{
                    type: 'empty',
                    prompt: 'Please select a Role'
                }]
            },
            status: {
                identifier: 'status',
                rules: [{
                    type: 'empty',
                    prompt: 'Please select a Status'
                }]
            },
            password: {
                identifier: 'password',
                rules: [{
                    type: 'empty',
                    prompt: 'Please enter a Password'
                }]
            },
            password_confirmation: {
                identifier: 'password_confirmation',
                rules: [{
                    type: 'match[password]',
                    prompt: 'Please confirm Password'
                }]
            },
        }
    });

    $('#edit_user_form').form({
        fields: {
            role_id: {
                identifier: 'role_id',
                rules: [{
                    type: 'empty',
                    prompt: 'Please select a Role'
                }]
            },
            status: {
                identifier: 'status',
                rules: [{
                    type: 'empty',
                    prompt: 'Please select a Status'
                }]
            },
        }
    });

    $('#add_role_form, #edit_role_form').form({
        fields: {
            role_name: {
                identifier: 'role_name',
                rules: [{
                    type: 'empty',
                    prompt: 'Please enter a Role name'
                }]
            },
            state: {
                identifier: 'state',
                rules: [{
                    type: 'empty',
                    prompt: 'Please select a Status'
                }]
            },
        }
    });

    $('#update_profile_form').form({
        fields: {
            name: {
                identifier: 'name',
                rules: [{
                    type: 'empty',
                    prompt: 'Please enter your User name'
                }]
            },
            email: {
                identifier: 'email',
                rules: [{
                    type: 'email',
                    prompt: 'Please enter your User email'
                }]
            },
        }
    });

    $('#change_password_form').form({
        fields: {
            currentpassword: {
                identifier: 'currentpassword',
                rules: [{
                    type: 'empty',
                    prompt: 'Please enter your Current password'
                }]
            },
            newpassword: {
                identifier: 'newpassword',
                rules: [{
                    type: 'empty',
                    prompt: 'Please enter your New password'
                }]
            },
            confirmpassword: {
                identifier: 'confirmpassword',
                rules: [{
                    type: 'empty',
                    prompt: 'Please confirm your New password'
                }]
            },
        }
    });

})();
